#
# Configuration file for using the gnomecanvaspixbuf library in GNOME applications
#
GNOMECANVASPIXBUF_LIBDIR="-L/usr/lib64"
GNOMECANVASPIXBUF_LIBS="-L/usr/lib64 -rdynamic -lgmodule -lglib -ldl -lgdk_pixbuf -L/usr/lib64 -L/usr/X11R6/lib64 -lgtk -lgdk -rdynamic -lgmodule -lglib -ldl -lXext -lX11 -lm -lgnomecanvaspixbuf"
GNOMECANVASPIXBUF_INCLUDEDIR="-I/usr/include/gdk-pixbuf-1.0 -I/usr/include/gtk-1.2 -I/usr/include/glib-1.2 -I/usr/lib64/glib/include -I/usr/X11R6/include"
MODULE_VERSION="gnomecanvaspixbuf-0.22.0"
